@@ -1,13 +1,13 @@
 /*
  *  odbcinst.h
  *
- *  $Id: odbcinst.h,v 1.2 2006/01/20 15:58:34 source Exp $
+ *  $Id$
  *
  *  iODBC Installer defines
  *
  *  The iODBC driver manager.
  *
- *  Copyright (C) 1996-2006 by OpenLink Software <iodbc@openlinksw.com>
+ *  Copyright (C) 1996-2014 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
@@ -130,6 +130,22 @@ extern "C" {
 #  endif
 #endif
 
+#ifndef DEFAULT_FILEDSNPATH
+#  if defined(__BEOS__)
+#    define DEFAULT_FILEDSNPATH	"/boot/beos/etc/ODBCDataSources"
+#  elif defined(macintosh)
+#    ifdef __POWERPC__
+#      define DEFAULT_FILEDSNPATH "Boot:System Folder:Preferences:ODBC Preferences PPC:ODBCDataSources"
+#    else
+#      define DEFAULT_FILEDSNPATH "Boot:System Folder:Preferences:ODBC Preferences:ODBCDataSources"
+#    endif
+#  elif defined (__APPLE__)
+#    define DEFAULT_FILEDSNPATH	"/Library/ODBC/ODBCDataSources"
+#  else
+#    define DEFAULT_FILEDSNPATH	"/etc/ODBCDataSources"
+#  endif
+#endif
+
 #define USERDSN_ONLY  0
 #define SYSTEMDSN_ONLY  1
 
