@@ -1,14 +1,14 @@
 /*
  *  henv.h
  *
- *  $Id: henv.h,v 1.19 2006/01/24 00:09:25 source Exp $
+ *  $Id$
  *
  *  Environment object management functions
  *
  *  The iODBC driver manager.
  *
  *  Copyright (C) 1995 by Ke Jin <kejin@empress.com>
- *  Copyright (C) 1996-2006 by OpenLink Software <iodbc@openlinksw.com>
+ *  Copyright (C) 1996-2014 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
@@ -96,6 +96,14 @@ enum odbcapi_t
   } ;
 
 
+#if (ODBCVER >= 0x300)
+/*
+ * SQL_ATTR_CONNECTION_POOLING value
+ */
+extern SQLINTEGER _iodbcdm_attr_connection_pooling;
+#endif
+
+
 typedef struct
   {
     int type;			/* must be 1st field */
@@ -107,6 +115,11 @@ typedef struct
     int state;
 #if (ODBCVER >= 0x300)
     SQLUINTEGER odbc_ver;    /* ODBC version of the application */
+
+    SQLINTEGER connection_pooling; /* SQL_ATTR_CONNECTION_POOLING value at the
+				      time of env creation */
+    SQLINTEGER cp_match;	/* connection pool matching method */
+    struct DBC *pdbc_pool;	/* connection pool */
 #endif    
 
     SQLSMALLINT err_rec;
